@@ -7,7 +7,7 @@ from typing import Any
 
 from switchbot.models import SwitchBotAdvertisement
 
-from .device import SwitchbotDevice
+from .device import SwitchbotDevice, SwitchbotSequenceDevice
 
 REQ_HEADER = "570f"
 BULB_COMMMAND_HEADER = "4701"
@@ -25,16 +25,11 @@ CW_KEY = f"{BULB_COMMAND}17"
 
 _LOGGER = logging.getLogger(__name__)
 
-
-class ColorMode(Enum):
-
-    OFF = 0
-    COLOR_TEMP = 1
-    RGB = 2
-    EFFECT = 3
+from .device import ColorMode
+from .base_light import SwitchbotBaseLight
 
 
-class SwitchbotBulb(SwitchbotDevice):
+class SwitchbotBulb(SwitchbotBaseLight):
     """Representation of a Switchbot bulb."""
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
@@ -43,41 +38,9 @@ class SwitchbotBulb(SwitchbotDevice):
         self._state: dict[str, Any] = {}
 
     @property
-    def on(self) -> bool | None:
-        """Return if bulb is on."""
-        return self.is_on()
-
-    @property
-    def rgb(self) -> tuple[int, int, int] | None:
-        """Return the current rgb value."""
-        if "r" not in self._state or "g" not in self._state or "b" not in self._state:
-            return None
-        return self._state["r"], self._state["g"], self._state["b"]
-
-    @property
-    def color_temp(self) -> int | None:
-        """Return the current color temp value."""
-        return self._state.get("cw") or self.min_temp
-
-    @property
-    def brightness(self) -> int | None:
-        """Return the current brightness value."""
-        return self._get_adv_value("brightness") or 0
-
-    @property
-    def color_mode(self) -> ColorMode:
-        """Return the current color mode."""
-        return ColorMode(self._get_adv_value("color_mode") or 0)
-
-    @property
-    def min_temp(self) -> int:
-        """Return minimum color temp."""
-        return 2700
-
-    @property
-    def max_temp(self) -> int:
-        """Return maximum color temp."""
-        return 6500
+    def color_modes(self) -> set[ColorMode]:
+        """Return the supported color modes."""
+        return {ColorMode.RGB, ColorMode.COLOR_TEMP}
 
     async def update(self) -> None:
         """Update state of device."""
@@ -88,20 +51,20 @@ class SwitchbotBulb(SwitchbotDevice):
         """Turn device on."""
         result = await self._sendcommand(BULB_ON_KEY)
         self._update_state(result)
-        return result[1] == 0x80
+        return self._check_command_result(result, 1, {0x80})
 
     async def turn_off(self) -> bool:
         """Turn device off."""
         result = await self._sendcommand(BULB_OFF_KEY)
         self._update_state(result)
-        return result[1] == 0x00
+        return self._check_command_result(result, 1, {0x00})
 
     async def set_brightness(self, brightness: int) -> bool:
         """Set brightness."""
         assert 0 <= brightness <= 100, "Brightness must be between 0 and 100"
         result = await self._sendcommand(f"{BRIGHTNESS_KEY}{brightness:02X}")
         self._update_state(result)
-        return result[1] == 0x80
+        return self._check_command_result(result, 1, {0x80})
 
     async def set_color_temp(self, brightness: int, color_temp: int) -> bool:
         """Set color temp."""
@@ -111,7 +74,7 @@ class SwitchbotBulb(SwitchbotDevice):
             f"{CW_BRIGHTNESS_KEY}{brightness:02X}{color_temp:04X}"
         )
         self._update_state(result)
-        return result[1] == 0x80
+        return self._check_command_result(result, 1, {0x80})
 
     async def set_rgb(self, brightness: int, r: int, g: int, b: int) -> bool:
         """Set rgb."""
@@ -123,11 +86,7 @@ class SwitchbotBulb(SwitchbotDevice):
             f"{RGB_BRIGHTNESS_KEY}{brightness:02X}{r:02X}{g:02X}{b:02X}"
         )
         self._update_state(result)
-        return result[1] == 0x80
-
-    def is_on(self) -> bool | None:
-        """Return bulb state from cache."""
-        return self._get_adv_value("isOn")
+        return self._check_command_result(result, 1, {0x80})
 
     def _update_state(self, result: bytes) -> None:
         """Update device state."""
@@ -141,18 +100,3 @@ class SwitchbotBulb(SwitchbotDevice):
             "%s: Bulb update state: %s = %s", self.name, result.hex(), self._state
         )
         self._fire_callbacks()
-
-    def update_from_advertisement(self, advertisement: SwitchBotAdvertisement) -> None:
-        """Update device data from advertisement."""
-        current_state = self._get_adv_value("sequence_number")
-        super().update_from_advertisement(advertisement)
-        new_state = self._get_adv_value("sequence_number")
-        _LOGGER.debug(
-            "%s: Bulb update advertisement: %s (seq before: %s) (seq after: %s)",
-            self.name,
-            advertisement,
-            current_state,
-            new_state,
-        )
-        if current_state != new_state:
-            asyncio.ensure_future(self.update())
