@@ -4,6 +4,7 @@ from __future__ import annotations
 import asyncio
 import binascii
 import logging
+from enum import Enum
 from typing import Any, Callable
 from uuid import UUID
 
@@ -41,10 +42,22 @@ BLEAK_EXCEPTIONS = (AttributeError, BleakError, asyncio.exceptions.TimeoutError)
 DISCONNECT_DELAY = 49
 
 
+class ColorMode(Enum):
+
+    OFF = 0
+    COLOR_TEMP = 1
+    RGB = 2
+    EFFECT = 3
+
+
 class CharacteristicMissingError(Exception):
     """Raised when a characteristic is missing."""
 
 
+class SwitchbotOperationError(Exception):
+    """Raised when an operation fails."""
+
+
 def _sb_uuid(comms_type: str = "service") -> UUID | str:
     """Return Switchbot UUID."""
 
@@ -396,3 +409,32 @@ class SwitchbotDevice:
 
     async def update(self) -> None:
         """Update state of device."""
+
+    def _check_command_result(
+        self, result: bytes, index: int, values: set[int]
+    ) -> bool:
+        """Check command result."""
+        if not result:
+            raise SwitchbotOperationError(
+                f"{self.name}: Sending command failed (rssi={self.rssi})"
+            )
+        return result[index] in values
+
+
+class SwitchbotSequenceDevice(SwitchbotDevice):
+    """A Switchbot sequence device."""
+
+    def update_from_advertisement(self, advertisement: SwitchBotAdvertisement) -> None:
+        """Update device data from advertisement."""
+        current_state = self._get_adv_value("sequence_number")
+        super().update_from_advertisement(advertisement)
+        new_state = self._get_adv_value("sequence_number")
+        _LOGGER.debug(
+            "%s: Strip update advertisement: %s (seq before: %s) (seq after: %s)",
+            self.name,
+            advertisement,
+            current_state,
+            new_state,
+        )
+        if current_state != new_state:
+            asyncio.ensure_future(self.update())
